searchData={"items":[{"type":"module","title":"UniqueNamesGenerator","doc":"Documentation for `UniqueNamesGenerator`.","ref":"UniqueNamesGenerator.html"},{"type":"function","title":"UniqueNamesGenerator.generate/2","doc":"Dictionaries list is required (at least one of `t:UniqueNamesGenerator.Impl.Dictionaries.dictionaries/0` and/or a custom list of strings). Config map optional.","ref":"UniqueNamesGenerator.html#generate/2"},{"type":"function","title":"Examples - UniqueNamesGenerator.generate/2","doc":"iex> UniqueNamesGenerator.generate([:colors, :animals], %{seed: \"hello\", style: :capital, separator: \" \"})\n    \"Lavender Marlin\"\n\n    iex> UniqueNamesGenerator.generate([:colors, :star_wars], %{seed: \"03bf0706-b7e9-33b8-aee5-c6142a816478\", style: :capital, separator: \" \"})\n    \"Brown Dooku\"\n\n    iex> drinks = [\"Sprite\", \"Coca-Cola\", \"Juice\", \"Tea\"]\n    iex(1)> UniqueNamesGenerator.generate([:colors, drinks, :numbers], %{seed: 50, style: :capital, separator: \"-\"})\n    \"Teal-Tea-902\"\n\n    iex> UniqueNamesGenerator.generate([:adjectives, :animals])\n    \"respectable_bear\"","ref":"UniqueNamesGenerator.html#generate/2-examples"},{"type":"module","title":"UniqueNamesGenerator.Impl.Dictionaries","doc":"Documentation for `UniqueNamesGenerator.Impl.Dictionaries`.","ref":"UniqueNamesGenerator.Impl.Dictionaries.html"},{"type":"function","title":"UniqueNamesGenerator.Impl.Dictionaries.generate/2","doc":"","ref":"UniqueNamesGenerator.Impl.Dictionaries.html#generate/2"},{"type":"type","title":"UniqueNamesGenerator.Impl.Dictionaries.dictionaries/0","doc":"","ref":"UniqueNamesGenerator.Impl.Dictionaries.html#t:dictionaries/0"},{"type":"type","title":"UniqueNamesGenerator.Impl.Dictionaries.options/0","doc":"","ref":"UniqueNamesGenerator.Impl.Dictionaries.html#t:options/0"},{"type":"type","title":"UniqueNamesGenerator.Impl.Dictionaries.style/0","doc":"","ref":"UniqueNamesGenerator.Impl.Dictionaries.html#t:style/0"},{"type":"extras","title":"README","doc":"![Elixir CI](https://github.com/jongirard/unique_names_generator/actions/workflows/elixir.yml/badge.svg)\n\n# UniqueNamesGenerator\n\nUnique Names Generator is an Elixir package for generating random and unique names. Generation utilizes PRNG (pseudo random number generation) for either fully random or seeded name generation. It comes with a list of various dictionaries out of the box, but you can also provide custom ones. Inspired by the great \"Unique Names Generator\" available on [NPM](https://www.npmjs.com/package/unique-names-generator) by Andrea Sonny.\n\nAPI Documentation built with [ExDoc](https://github.com/elixir-lang/ex_doc) can be found at  .","ref":"readme.html"},{"type":"extras","title":"Installation - README","doc":"The package can be installed from [Hex](https://hex.pm/docs/publish)\nby adding `unique_names_generator` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:unique_names_generator, \"~> 0.2.0\"}\n  ]\nend\n```\nThen run `mix deps.get`.","ref":"readme.html#installation"},{"type":"extras","title":"Usage - README","doc":"In a nutshell, you can begin generating randon names with UniqueNamesGenerator by simply specifying a list of one or more dictionaries via [generate/2](`UniqueNamesGenerator.generate/2`). Available dictionary types are `t:UniqueNamesGenerator.Impl.Dictionaries.dictionaries/0`.\n\n```elixir\nUniqueNamesGenerator.generate([:adjectives, :animals])\n# => Generates ex: \"dramatic_limpet\"\n\nUniqueNamesGenerator.generate([:adjectives, :colors, :animals])\n# => Generates ex: \"tremendous_brown_cat\"\n\nUniqueNamesGenerator.generate([:adjectives, :names, :numbers])\n# => Generates ex: \"doubtful_wanda_979\"\n```\n\nTo use custom dictionaries, simply include your list of strings as part of the dictionaries list:\n\n```elixir\ndrinks = [\"Sprite\", \"Coca-Cola\", \"Juice\", \"Tea\"]\nUniqueNamesGenerator.generate([:colors, drinks])\n# => Generates ex: \"cyan_sprite\"\n```\n\n#","ref":"readme.html#usage"},{"type":"extras","title":"Config options - README","doc":"UniqueNamesGenerator can be used with either the default provided config (`%{seperator: \"_\", style: :lowercase }`) or by specifying any of your own configuration options for seeding, seperator and style. See the options type, `t:UniqueNamesGenerator.Impl.Dictionaries.options/0`, for more details on possible options.\n\n```elixir\nUniqueNamesGenerator.generate([:colors, :animals], %{ style: :capital, separator: \" \" })\n# => Generates ex: \"Lavender Marlin\"\n```\n\n#","ref":"readme.html#config-options"},{"type":"extras","title":"Seeded Generation - README","doc":"A seed can be used to deterministically generate a name. As long as the provided seed is the same, then the generated name will also always be the same. Simply provide a string or integer in the [options config map](`t:UniqueNamesGenerator.Impl.Dictionaries.options/0`) of the seed key, ie; `%{ seed: \"hello\" }`. \n\n_(**Usecase example:** generate a username for an authenticated user based on UUID. Ex: `03bf0706-b7e9-33b8-aee5-c6142a816478` will always generate the name \"brown_dooku_247\" when used together with the colors/star_wars/numbers dictionaries)._\n\n```elixir\nUniqueNamesGenerator.generate([:colors, :star_wars, :numbers], %{ seed: \"03bf0706-b7e9-33b8-aee5-c6142a816478\" })\n# => Seed \"03bf0706-b7e9-33b8-aee5-c6142a816478\" always generates: \"brown_dooku_247\"\n```","ref":"readme.html#seeded-generation"},{"type":"extras","title":"License - README","doc":"This project is licensed under the MIT License - see the [LICENSE file](https://github.com/jongirard/unique_names_generator/blob/development/LICENSE) for details.","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"0.2.0 (03.09.2024) - Changelog","doc":"#","ref":"changelog.html#0-2-0-03-09-2024"},{"type":"extras","title":"Changes - Changelog","doc":"* Implement new `:numbers` dictionary type for dynamic number generation\n* Refactor dictionary retrieval/loading mechanism (store dictionaries as modules rather than reading from asset files)\n\n#","ref":"changelog.html#changes"},{"type":"extras","title":"Bug fixes - Changelog","doc":"* Fix issue which would cause dictionary words containing a space character to be split into multiple words\n* Fix issue where separator would not be applied to words containing whitespace","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"0.1.0 (03.07.2024) - Changelog","doc":"* Initial release","ref":"changelog.html#0-1-0-03-07-2024"},{"type":"extras","title":"LICENSE","doc":"MIT License\n\nCopyright (c) 2024 Jon Girard\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"content_type":"text/markdown"}